@@ -60,7 +60,7 @@ class JWTAuthenticationWithLastLogin(JWTAuthentication):
     Usage:
         Add to REST_FRAMEWORK settings:
         'DEFAULT_AUTHENTICATION_CLASSES': [
-            'django_cfg.apps.accounts.authentication.JWTAuthenticationWithLastLogin',
+            'django_cfg.apps.business.accounts.authentication.JWTAuthenticationWithLastLogin',
         ]
     """
 
